==> exo.ecm.wcm.component.wcm-1.1rc2-sources.jar: org/exoplatform/services/wcm/core/impl/WebSchemaModificationAction.java <==
/*
 * Copyright (C) 2003-2008 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.services.wcm.core.impl;

import javax.jcr.Node;
import javax.jcr.Property;

import org.apache.commons.chain.Context;
import org.apache.commons.logging.Log;
import org.exoplatform.container.ExoContainer;
import org.exoplatform.container.ExoContainerContext;
import org.exoplatform.services.command.action.Action;
import org.exoplatform.services.jcr.ext.common.SessionProvider;
import org.exoplatform.services.log.ExoLogger;
import org.exoplatform.services.wcm.core.WebSchemaConfigService;
/**
 * Created by The eXo Platform SAS
 * Author : Hoa Pham	
 *          hoa.pham@exoplatform.com
 * Sep 17, 2008  
 */
public class WebSchemaModificationAction implements Action{
  private Log log = ExoLogger.getLogger("wcm:WebSchemaModificationAction");
  public boolean execute(Context context) throws Exception {
    Property property = (Property)context.get("currentItem");
    String propertyName = property.getName();
    if(!propertyName.equals("jcr:data"))
      return propertyName.equalsIgnoreCase("exo:active");//use exo:active in case of exo:cssFile or exo:jsFile
    Node grandParent = property.getParent().getParent();
    if(!grandParent.getPrimaryNodeType().getName().equals("nt:file")) 
      return false;        
    ExoContainer container = ExoContainerContext.getCurrentContainer();
    WebSchemaConfigService schemaConfigService = 
      (WebSchemaConfigService) container.getComponentInstanceOfType(WebSchemaConfigService.class);
    SessionProvider sessionProvider = SessionProvider.createSystemProvider();
    try {            
      schemaConfigService.updateSchemaOnModify(grandParent, sessionProvider);
    } catch (Exception e) { 
      log.error("Error when update schema when modify node: "+grandParent.getPath() , e);
    }       
    sessionProvider.close();
    return true;    
  }

}

==> exo.ecm.wcm.component.wcm-1.2-sources.jar: org/exoplatform/services/wcm/core/impl/WebSchemaModificationAction.java <==
/*
 * Copyright (C) 2003-2008 eXo Platform SAS.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see<http://www.gnu.org/licenses/>.
 */
package org.exoplatform.services.wcm.core.impl;

import javax.jcr.Node;
import javax.jcr.Property;

import org.apache.commons.chain.Context;
import org.apache.commons.logging.Log;
import org.exoplatform.container.ExoContainer;
import org.exoplatform.container.ExoContainerContext;
import org.exoplatform.portal.webui.util.SessionProviderFactory;
import org.exoplatform.services.command.action.Action;
import org.exoplatform.services.jcr.ext.common.SessionProvider;
import org.exoplatform.services.log.ExoLogger;
import org.exoplatform.services.wcm.core.WebSchemaConfigService;
/**
 * Created by The eXo Platform SAS
 * Author : Hoa Pham	
 *          hoa.pham@exoplatform.com
 * Sep 17, 2008  
 */
public class WebSchemaModificationAction implements Action{
  private Log log = ExoLogger.getLogger("wcm:WebSchemaModificationAction");
  public boolean execute(Context context) throws Exception {
    Property property = (Property)context.get("currentItem");
    String propertyName = property.getName();
    if(!propertyName.equals("jcr:data"))
      return propertyName.equalsIgnoreCase("exo:active");//use exo:active in case of exo:cssFile or exo:jsFile
    Node grandParent = property.getParent().getParent();
    if(!grandParent.getPrimaryNodeType().getName().equals("nt:file")) 
      return false;        
    ExoContainer container = ExoContainerContext.getCurrentContainer();
    WebSchemaConfigService schemaConfigService = 
      (WebSchemaConfigService) container.getComponentInstanceOfType(WebSchemaConfigService.class);
    SessionProvider sessionProvider = SessionProviderFactory.createSystemProvider();
    try {            
      schemaConfigService.updateSchemaOnModify(grandParent, sessionProvider);
    } catch (Exception e) { 
      log.error("Error when update schema when modify node: "+grandParent.getPath() , e);
    }       
    sessionProvider.close();
    return true;    
  }

}
